@@ -303,7 +303,6 @@ function AreaChart(dualYaxis) {
 				return pathLen(d3.select(this)) + ' ' + pathLen(d3.select(this))
 			})
 			.duration(2000)
-			.ease('linear')
 			.attr('stroke-dashoffset', 0);
 		// remove elements
 		path.exit().remove();
@@ -825,8 +824,8 @@ function BarChart(dualYaxis) {
 			.attr('width', function (d, i) { return xScale.rangeBand() / 2; })
 			.attr('height', 0)
 			.transition()
-			.duration(200)
-			.delay(function (d, i) { return i * 50; })
+			.delay(function (d, i) { return i / data.length * 1000; })
+			.duration(500)
 			.attr('y', function (d, i) { return yScale0(d[1]); })
 			.attr('height', function (d, i) { return innerH() - yScale0(d[1]); });
 		// update
@@ -851,8 +850,8 @@ function BarChart(dualYaxis) {
 			.attr('width', function (d, i) { return xScale.rangeBand() / 2; })
 			.attr('height', 0)
 			.transition()
-			.duration(200)
-			.delay(function (d, i) { return i * 50; })
+			.delay(function (d, i) { return i / data.length * 1000; })
+			.duration(500)
 			.attr('y', function (d, i) { return yScale1(d[2]); })
 			.attr('height', function (d, i) { return innerH() - yScale1(d[2]); });
 		// update
